#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_smarteam_integ_interfaces.sti_db_item import StiDBItem
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class StiDBChildren(AnyObject):
    """

    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     StiDBChildren
            |
            | Represents all the Children of a CATIAStiDBItem.
            |
            | For each Child, we are able to retrieve its associated CATIAStiDBItem and the
            | Link Type (between itself and its father).
            | It should be represented as the following Correspondance Table { Child Number /
            | CATIAStiDBItem / Link Type}.
            |
            | Example:
            |
            |       The following example presents an Assembly structure and the associated
            |       Correspondance Tables for each element.
            |
            |      +-----------+
            |      \|  Product  \|<-----------------+
            |      +-----------+                  \|
            |         \|                           \|
            |         \|                           \|
            |         \|                           \|
            |        \|                           \|
            |         \|                           \|
            |         \|   +-----------------+     \|
            |         +-->\| Reference Part  \|     \|Contextual Link
            |         \|   +-----------------+     \|
            |         \|            ^              \|
            |         \|            \|              \|
            |         \|            \| Design Link  \|
            |         \|            \|              \|
            |         \|            \|              \|
            |         \|   +-----------------+     \|
            |         +-->\| Contextual Part \|-----+
            |             +-----------------+
            |
            |
            |     CATIAStiDBChildren for Product Child Number 	CATIAStiDBItem 	Link
            |     Type
            |     Child n°1 	Reference Part 	Product Link
            |     Child n°2 	Contextual Part 	Product Link
            |
            |     CATIAStiDBChildren for Contextual Part Child Number 	CATIAStiDBItem 	Link
            |     Type
            |     Child n°1 	Reference Part 	Design Link
            |     Child n°2 	Product 	Contextual Link
            |
            |     CATIAStiDBChildren for Reference Part Child Number 	CATIAStiDBItem 	Link
            |     Type
            |
            |     Here is the List of all CATIA Link Types :
            |
            |     CATIA Link Behavior 	Description
            |     CATIA Product Link 	Defines the basic Product Structure Link -i.e.: the
            |     link between either a Product and its Sub-Products or a Product and its
            |     Representation
            |     CATIA Design Link 	Defines Design Link -i.e.: Part to Part Link created
            |     with 'Copy/Paste ... with link' or as Contextual Link It can also be used for
            |     Link to external Parameters
            |     CATIA Design Table Link 	Defines the Link to a Design
            |     Table
            |     CATIA Rule Base Link 	Defines the Link to Document defining Rule
            |     Base
            |     CATIA Downstream Application Link 	Defines for instance the Link between a
            |     Drawing or an Analysis Document and a Part Document
            |     CATIA Contextual Link 	Defines the Link from a Part Document to its
            |     Context
            |     CATIA Result Link 	Defines the Link to "Result" document, like Analysis
            |     Reports, ...
            |     CATIA Is Composed Of Link 	Defines a simple "Composed Of" Link, like a
            |     Catalog Document Composed Of Sub-Catalog Documents
            |     CATIA Reference Link 	Defines any kind of Link that does not belong to one
            |     type described above including for instance OLE links, Link from a Catalog
            |     Document to a Part, Link to Material Document, ...
            |
            | See also:
            |     StiDBItem
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sti_db_children = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the Number of Children currently gathered in
                |     CATIAStiDBChildren.
                | 
                |     Returns:
                |         This output corresponds to the Children Number of a CATIAStiDBItem.
                |         
                |     Example:
                | 
                |               This example retrieves in  lChildrenNumber the Number of children
                |               currently gathered in oStiDBChildren.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR("E:/CATIAFiles/Assembly.CATProduct")
                |          Dim oStiDBChildren As StiDBChildren
                |          Set oStiDBChildren = oStiDBItem.GetChildren()
                |          (...)
                |          Dim oNbChildren As long
                |          oNbChildren = oStiDBChildren.Count

        :rtype: int
        """

        return self.sti_db_children.Count

    def item(self, i_index: cat_variant) -> StiDBItem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As StiDBItem
                | 
                |     Returns the CATIAStiDBItem from its index in the
                |     CATIAStiDBChildren.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             This input corresponds to the Index of the CATIAStiDBItem to
                |             retrieve from the CATIAStiDBChildren. This index is the rank of the
                |             CATIAStiDBItem in the CATIAStiDBChildren -list of all the Children of a
                |             CATIAStiDBItem. The index of the first CATIAStiDBItem is '1' and the index of
                |             the last CATIAStiDBItem is 'Count'. 
                | 
                |     Returns:
                |         This ouptut corresponds to the retrieved CATIAStiDBItem from its index.
                |         
                |     Example:
                | 
                |           The following example returns in oChildStiDBItem the third
                |           CATIAStiDBItem
                |          gathered in oStiDBChildren.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oFatherStiDBItem As StiDBItem
                |          Set oFatherStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR("E:\\CATIAFiles\\Assembly.CATProduct")
                |          Dim oStiDBChildren As StiDBChildren
                |          Set oStiDBChildren = oFatherStiDBItem.GetChildren()
                |          (...)
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiDBChildren.Item(3)

        :param cat_variant i_index:
        :rtype: StiDBItem
        """
        return StiDBItem(self.sti_db_children.Item(i_index))

    def link_type(self, i_index: cat_variant) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func LinkType(CATVariant iIndex) As CATBSTR
                | 
                |     Returns the Link Type from its index in the
                |     CATIAStiDBChildren.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             This input corresponds to the index of the Link Type to retrieve
                |             from the CATIAStiDBChildren. This index is the rank of the Link Type in the
                |             CATIAStiDBChildren. The index of the first Link Type is '1' and the index of
                |             the last Link Type is 'Count'. 
                | 
                |     Returns:
                |         This ouptut corresponds to the retrieved Link Type from its index.
                |         
                |     Example:
                | 
                |           The following example returns in oLinkType the third Link Type
                |           
                |          gathered in oStiDBChildren.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oFatherStiDBItem As StiDBItem
                |          Set oFatherStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR("E:\\CATIAFiles\\Assembly.CATProduct")
                |          Dim oStiDBChildren As StiDBChildren
                |          Set oStiDBChildren = oFatherStiDBItem.GetChildren()
                |          (...)
                |          Dim oLinkType As CATBSTR
                |          oLinkType = oStiDBChildren.LinkType(3)

        :param cat_variant i_index:
        :rtype: str
        """
        return self.sti_db_children.LinkType(i_index)

    def __repr__(self):
        return f'StiDBChildren(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class AssemblyFeature(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AssemblyFeature
                | 
                | Represents the AssemblyFeature object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_feature = com_object

    def add_affected_component(self, i_component: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddAffectedComponent(Product iComponent)
                | 
                |     Adds a component to the affected component list. An update of the
                |     aggregating Product is necessary to apply the Assembly Feature to this
                |     component.
                | 
                |     Parameters:
                | 
                |         iComponent
                |             The component to affect 
                | 
                |     Example:
                |         The following example adds the component ProdToAffect to the affected
                |         component list of the AssemblyFeature assemblyFeat.
                | 
                |          assemblyFeat.AddAffectedComponent( ProdToAffect )

        :param Product i_component:
        :rtype: None
        """
        return self.assembly_feature.AddAffectedComponent(i_component.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_affected_component'
        # # vba_code = """
        # # Public Function add_affected_component(assembly_feature)
        # #     Dim iComponent (2)
        # #     assembly_feature.AddAffectedComponent iComponent
        # #     add_affected_component = iComponent
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def affected_components_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AffectedComponentsCount() As long
                | 
                |     Returns the affected component list count.
                | 
                |     Example:
                |         The following example retrieves the affected component list count of
                |         the AssemblyFeature assemblyFeat in affectedListSize.
                | 
                |          affectedListSize = assemblyFeat.AffectedComponentsCount

        :rtype: int
        """
        return self.assembly_feature.AffectedComponentsCount()

    def list_affected_components(self, o_list_of_components: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListAffectedComponents(CATSafeArrayVariant
                | oListOfComponents)
                | 
                |     Retrieves the affected component list.
                | 
                |     Parameters:
                | 
                |         oListOfComponents
                |             The retrieved list.
                |             The array must be previously initialized using the
                |             
                | 
                |         AffectedComponentsCount method. 
                | 
                | Example:
                |     The following example retrieves the affected component list of the
                |     AssemblyFeature assemblyFeat in affectedList.
                | 
                |      affectedListSize = assemblyFeat.AffectedComponentsCount
                |      Dim affectedList(affectedListSize-1) 
                |      assemblyFeat.ListAffectedComponents(affectedList)

        :param tuple o_list_of_components:
        :rtype: None
        """
        return self.assembly_feature.ListAffectedComponents(o_list_of_components)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_affected_components'
        # # vba_code = """
        # # Public Function list_affected_components(assembly_feature)
        # #     Dim oListOfComponents (2)
        # #     assembly_feature.ListAffectedComponents oListOfComponents
        # #     list_affected_components = oListOfComponents
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_affected_component(self, i_component: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAffectedComponent(Product iComponent)
                | 
                |     Removes a component from the affected component list. An update of the
                |     aggregating Product is necessary to remove the generated feature from this
                |     component.
                | 
                |     Parameters:
                | 
                |         iComponent
                |             The affected component to remove 
                | 
                |     Example:
                |         The following example removes the component ProdToRemove from the
                |         affected component list of the AssemblyFeature
                |         assemblyFeat.
                | 
                |          assemblyFeat.RemoveAffectedComponent( ProdToRemove )

        :param Product i_component:
        :rtype: None
        """
        return self.assembly_feature.RemoveAffectedComponent(i_component.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_affected_component'
        # # vba_code = """
        # # Public Function remove_affected_component(assembly_feature)
        # #     Dim iComponent (2)
        # #     assembly_feature.RemoveAffectedComponent iComponent
        # #     remove_affected_component = iComponent
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AssemblyFeature(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.move import Move
from pycatia.system_interfaces.any_object import AnyObject


class ArrangementNode(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrangementNode
                | 
                | This interface provides access to a CATIAArrangementNode
                | object.
                | Use this object to fetch the properties of an ArrangementNode object. Role: Use
                | this object to retrieve the bend angle, bend radius and location of an
                | ArrangementNode object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arrangement_node = com_object

    @property
    def bend_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BendAngle() As double (Read Only)
                | 
                |     Returns the BendAngle of the current ArrangementNode.
                | 
                |     Example:
                |         This example retrieves the BendAngle of the objNode1
                |         object.
                | 
                |          Dim dblBendAngle   As Double
                |          dblBendBendAngle  = objNode1.BendAngle

        :rtype: float
        """

        return self.arrangement_node.BendAngle

    @property
    def bend_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BendRadius() As double
                | 
                |     Returns or sets the BendRadius of the current
                |     ArrangementNode.
                | 
                |     Example:
                |         This example retrieves the BendRadius of the objNode1
                |         object.
                | 
                |          Dim dblBendRadius   As Double
                |          dblBendRadius  = objNode1.BendRadius

        :rtype: float
        """

        return self.arrangement_node.BendRadius

    @bend_radius.setter
    def bend_radius(self, value: float):
        """
        :param float value:
        """

        self.arrangement_node.BendRadius = value

    def get_point(self, i_rel_axis: Move, io_node_location: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPoint(Move iRelAxis,
                | CATSafeArrayVariant ioNodeLocation)
                | 
                |     Returns the location of the current ArrangementNode.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             The relative axis to be considered when calculating the coordinate.
                |             
                |         ioNodeLocation
                |             The location of the ArrangementNode.
                | 
                |             Example:
                |                 This example retrieves the location of the ArrangementNode
                |                 object objNode1.
                | 
                |                  Dim dblCoords(3)   As Double
                |                  Dim iRelAxis       As Move
                |                  'Fetch iRelAxis from the object containing the
                |                  node
                |                  ...
                |                  objNode1.GetPoint(iRelAxis, dblCoords)

        :param Move i_rel_axis:
        :param tuple io_node_location:
        :rtype: None
        """
        return self.arrangement_node.GetPoint(i_rel_axis.com_object, io_node_location)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_point'
        # # vba_code = """
        # # Public Function get_point(arrangement_node)
        # #     Dim iRelAxis (2)
        # #     arrangement_node.GetPoint iRelAxis
        # #     get_point = iRelAxis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_point(self, i_rel_axis: Move, i_node_location: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPoint(Move iRelAxis,
                | CATSafeArrayVariant iNodeLocation)
                | 
                |     Sets the location of the current ArrangementNode.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             The relative axis to be considered when calculating the coordinate.
                |             
                |         ioNodeLocation
                |             The location of the ArrangementNode.
                | 
                |             Example:
                |                 This example sets the location of the ArrangementNode object
                |                 objNode1.
                | 
                |                  Dim dblCoords(3)   As Double
                |                  Dim iRelAxis       As Move
                |                  'Fetch iRelAxis from the object containing the
                |                  node
                |                  ...
                |                  dblCoords(0)       = 300.0 '//X
                |                  dblCoords(1)       = 500.0 '//Y
                |                  dblCoords(2)       = 300.0 '//Z
                |                  objNode1.SetPoint(iRelAxis, dblCoords)

        :param Move i_rel_axis:
        :param tuple i_node_location:
        :rtype: None
        """
        return self.arrangement_node.SetPoint(i_rel_axis.com_object, i_node_location)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_point'
        # # vba_code = """
        # # Public Function set_point(arrangement_node)
        # #     Dim iRelAxis (2)
        # #     arrangement_node.SetPoint iRelAxis
        # #     set_point = iRelAxis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrangementNode(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchMovable(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchMovable
                | 
                | Manage the transformation of a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_movable = com_object

    def rotate(self, i_db1_rotation_angle_in_radian: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Rotate(double iDb1RotationAngleInRadian)
                | 
                |     Rotate a schematic object with an angle in radian.
                | 
                |     Parameters:
                | 
                |         iDb1RotationAngleInRadian
                |             Rotation angle (from x-axis) in radian. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchMovable
                | 
                |           ...
                |          objThisIntf.Rotate

        :param float i_db1_rotation_angle_in_radian:
        :rtype: None
        """
        return self.sch_movable.Rotate(i_db1_rotation_angle_in_radian)

    def scale(self, i_db1_scale_factor: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Scale(double iDb1ScaleFactor)
                | 
                |     Scale a schematic object with a scale factor.
                | 
                |     Parameters:
                | 
                |         oDb1ScaleFactor
                |             The current scale factor of the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchMovable
                | 
                |           ...
                |          objThisIntf.Scale

        :param float i_db1_scale_factor:
        :rtype: None
        """
        return self.sch_movable.Scale(i_db1_scale_factor)

    def scale_selected_objects(self, i_l_cntbl_to_scale: SchListOfObjects, i_db1_scale_factor: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ScaleSelectedObjects(SchListOfObjects iLCntblToScale,
                | double iDb1ScaleFactor)
                | 
                |     Scale a list of schematic objects with a scale factor.
                | 
                |     Parameters:
                | 
                |         iLCntblToScale
                |             List of selected objects to scale. 
                |         oDb1ScaleFactor
                |             The current scale factor. 
                | 
                |     Example:
                | 
                |          Dim objThisIntf As SchMovable
                |          Dim objArg1 As SchListOfObjects
                | 
                |           ...
                |          objThisIntf.ScaleSelectedObjectsobjArg1,objArg1

        :param SchListOfObjects i_l_cntbl_to_scale:
        :param float i_db1_scale_factor:
        :rtype: None
        """
        return self.sch_movable.ScaleSelectedObjects(i_l_cntbl_to_scale.com_object, i_db1_scale_factor)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'scale_selected_objects'
        # # vba_code = """
        # # Public Function scale_selected_objects(sch_movable)
        # #     Dim iLCntblToScale (2)
        # #     sch_movable.ScaleSelectedObjects iLCntblToScale
        # #     scale_selected_objects = iLCntblToScale
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def transform(self, i_db6_trans_matrix: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Transform(CATSafeArrayVariant iDb6TransMatrix)
                | 
                |     Transform a schematic object with a transformation matrix.
                | 
                |     Parameters:
                | 
                |         iDb6TransMatrix
                |             Transformation matrix. See 
                | 
                |         SchGRRComp.GetTransformation2D for explanation of this argument.
                |         
                |     Example:
                |
                |          Dim objThisIntf As SchMovable
                |          Dim dbVar1(6) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.TransformdbVar1

        :param tuple i_db6_trans_matrix:
        :rtype: tuple
        """
        return self.sch_movable.Transform(i_db6_trans_matrix)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'transform'
        # # vba_code = """
        # # Public Function transform(sch_movable)
        # #     Dim iDb6TransMatrix (2)
        # #     sch_movable.Transform iDb6TransMatrix
        # #     transform = iDb6TransMatrix
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def translate(self, i_db2_vector: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Translate(CATSafeArrayVariant iDb2Vector)
                | 
                |     Translate a schematic object with a vector.
                | 
                |     Parameters:
                | 
                |         iDb2Vector
                |             X-Y components of a translation vector. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchMovable
                |          Dim dbVar1(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.TranslatedbVar1

        :param tuple i_db2_vector:
        :rtype: tuple
        """
        return self.sch_movable.Translate(i_db2_vector)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'translate'
        # # vba_code = """
        # # Public Function translate(sch_movable)
        # #     Dim iDb2Vector (2)
        # #     sch_movable.Translate iDb2Vector
        # #     translate = iDb2Vector
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchMovable(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.workbench import Workbench
from pycatia.osm_interfaces.scenes import Scenes


class SceneWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         SceneWorkbench
                | 
                | Represent the access point to scenes management.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.scene_workbench = com_object

    @property
    def work_scenes(self) -> Scenes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WorkScenes() As Scenes (Read Only)
                | 
                |     Returns the Scenes collection.
                | 
                |     Example:
                | 
                |               This example retrieves the WorkScenes collection of the active
                |               document.
                |
                |             Dim TheWorkSceneWorkbench As Workbench
                |             Set TheWorkSceneWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SceneWorkbench" )
                |             Dim TheScenesList As WorkScenes
                |             Set TheScenesList = TheWorkSceneWorkbench.WorkScenes

        :rtype: Scenes
        """

        return Scenes(self.scene_workbench.WorkScenes)

    def __repr__(self):
        return f'SceneWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_body_element import SWKBodyElement
from pycatia.dnb_human_modeling_interfaces.swkdof import SWKDOF


class SWKLineOfSight(SWKBodyElement):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKBodyElement
                |                         SWKLineOfSight
                | 
                | This interface deals with a line of sight of a manikin.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_line_of_sight = com_object

    @property
    def length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Length() As double (Read Only)
                | 
                |     Returns the length of the line of sight, in centimeters.
                |     If the the value returned is -1.0, then it means that this line of sight
                |     has infinite length.

        :rtype: float
        """

        return self.swk_line_of_sight.Length

    @property
    def nb_do_fs(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbDOFs() As long (Read Only)
                | 
                |     Returns the number of degrees of freedom on the current line of sight. This
                |     property will always be equal to 2. The two degrees of freedom on a line of
                |     sight are the up/down movement and the lateral right/lateral left movement.

        :rtype: int
        """

        return self.swk_line_of_sight.NbDOFs

    def apply_position(self, pi_position_increment: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyPosition(CATSafeArrayVariant piPositionIncrement)
                | 
                |     Applies a new relative position for the line of sight.
                | 
                |     Parameters:
                | 
                |         piPositionIncrement
                |             The new position to combine with the line of sight's current
                |             position.
                |             This array must contain 12 numbers, and msut be initialized using
                |             the four columns of a transformation matrix. The first nine components
                |             represent the rotation matrix.
                |             The last three components represent the translation
                |             vector.
                | 
                |     Example:
                | 
                |           This example sets the segment to a 45-degree rotation
                |           around
                |          the x axis and at a (10, 20, 30) translation from the
                |          origin.
                |
                |          Dim myPosition(11)
                |          'Rotation (45 degrees around the x axis)
                |          myPosition(0)  = 1.000
                |          myPosition(1)  = 0
                |          myPosition(2)  = 0
                |          myPosition(3)  = 0
                |          myPosition(4)  = 0.707
                |          myPosition(5)  = 0.707
                |          myPosition(6)  = 0
                |          myPosition(7)  = -0.707
                |          myPosition(8)  = 0.707
                |          'Translation vector (10,20,30)
                |          myPosition(9)  = 10.000
                |          myPosition(10) = 20.000
                |          myPosition(11) = 30.000
                |          myManikin.Body.GetItem("LLHeEye").ApplyPosition
                |          myPosition

        :param tuple pi_position_increment:
        :rtype: None
        """
        return self.swk_line_of_sight.ApplyPosition(pi_position_increment)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'apply_position'
        # # vba_code = """
        # # Public Function apply_position(swk_line_of_sight)
        # #     Dim piPositionIncrement (2)
        # #     swk_line_of_sight.ApplyPosition piPositionIncrement
        # #     apply_position = piPositionIncrement
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_dof(self, pi_dof_number: int) -> SWKDOF:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDOF(long piDOFNumber) As SWKDOF
                | 
                |     Returns a specific degree of freedom of the line of sight. A line of sight
                |     always has exactly two degrees of freedom. and these are numbered 0 and
                |     1.
                | 
                |     Parameters:
                | 
                |         piDOFNumber
                |             The index of the DOF to retrieve. This parameter must be either 0
                |             or 1.

        :param int pi_dof_number:
        :rtype: SWKDOF
        """
        return SWKDOF(self.swk_line_of_sight.GetDOF(pi_dof_number))

    def set_position(self, pi_new_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(CATSafeArrayVariant piNewPosition)
                | 
                |     Sets a new absolute position for the line of sight.
                | 
                |     Parameters:
                | 
                |         piNewPosition
                |             The new position to place the line of sight.
                |             This array must contain 12 numbers, and msut be initialized using
                |             the four columns of a transformation matrix. The first nine components
                |             represent the rotation matrix.
                |             The last three components represent the translation
                |             vector.
                | 
                |     Example:
                | 
                |           This example sets the line of sight to a 45-degree rotation
                |           around
                |          the x axis and at a (10, 20, 30) translation from the
                |          origin.
                |
                |          Dim myPosition(11)
                |          'Rotation (45 degrees around the x axis)
                |          myPosition(0)  = 1.000
                |          myPosition(1)  = 0
                |          myPosition(2)  = 0
                |          myPosition(3)  = 0
                |          myPosition(4)  = 0.707
                |          myPosition(5)  = 0.707
                |          myPosition(6)  = 0
                |          myPosition(7)  = -0.707
                |          myPosition(8)  = 0.707
                |          'Translation vector (10,20,30)
                |          myPosition(9)  = 10.000
                |          myPosition(10) = 20.000
                |          myPosition(11) = 30.000
                |          myManikin.Body.GetItem("LLHeEye").SetPosition
                |          myPosition

        :param tuple pi_new_position:
        :rtype: None
        """
        return self.swk_line_of_sight.SetPosition(pi_new_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_position'
        # # vba_code = """
        # # Public Function set_position(swk_line_of_sight)
        # #     Dim piNewPosition (2)
        # #     swk_line_of_sight.SetPosition piNewPosition
        # #     set_position = piNewPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SWKLineOfSight(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ArrSystemLineProduct(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrSystemLineProduct
                | 
                | The interface to access a CATIAArrSystemLineProduct
                | 
                | Using this prefered syntax will enable mkdoc to document your
                | class.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arr_system_line_product = com_object

    def get_sub_item(self, i_index: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSubItem(long iIndex) As AnyObject
                | 
                |     Allows the user to get the item at a specific index location.

        :param int i_index:
        :rtype: AnyObject
        """
        return AnyObject(self.arr_system_line_product.GetSubItem(i_index))

    def get_sub_products_count(self, i_intf_id: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSubProductsCount(CATBSTR iIntfId) As long
                | 
                |     Returns the count of the sub-products that make up the System-Line
                |     Arrangement Product and that match a specifc interface id. If the interface Id
                |     is NULL, then it searches for CATIAProduct objects by default.

        :param str i_intf_id:
        :rtype: int
        """
        return self.arr_system_line_product.GetSubProductsCount(i_intf_id)

    def __repr__(self):
        return f'ArrSystemLineProduct(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class CD5Property(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5Property
                | 
                | Represents a single property of an ENOVIA V6 object.
                | 
                | Role: It represents a single property tuple of a given object/document already
                | saved into ENOVIA. The purpose of this interface is to get the information of a
                | given property of an ENOVIA V6 object. The properties are accessible through
                | Edit/Properties menu item after user has clicked the ‘More…’
                | button
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve a single CD5Property from
                |       a collection CD5Properties.
                |      
                | 
                |      Dim objCD5Property As CD5Property
                |      Set objCD5Property = objCD5Properties.Item("0")
                |
                | See also:
                |     CD5Properties
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_property = com_object

    @property
    def property_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PropertyName() As CATBSTR (Read Only)
                | 
                |     Returns (gets) the name of the ENOVIA V6 object property.
                |     This is a readonly property.
                | 
                |     Throws:
                | 
                |         -1641847650 : Connection to ENOVIA V6 is necessary to intialize this option.
                | 
                |     Example:
                | 
                |           The following example retrieves Property Name
                |
                |          oCD5Property.PropertyName

        :rtype: str
        """

        return self.cd5_property.PropertyName

    @property
    def property_value(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PropertyValue() As CATBSTR (Read Only)
                | 
                |     Returns (gets) the value of the ENOVIA V6 object property.
                |     This is a readonly property.
                | 
                |     Throws:
                | 
                |         -1641847650 : Connection to ENOVIA V6 is necessary to intialize this option.
                | 
                |     Example:
                | 
                |           The following example retrieves Property Value
                |
                |          oCD5Property.PropertyValue

        :rtype: str
        """

        return self.cd5_property.PropertyValue

    def __repr__(self):
        return f'CD5Property(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.general_knowledge_interfaces.expert_report_object import ExpertReportObject
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ExpertReportObjects(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ExpertReportObjects
                | 
                | Represents the collection of (succeeded or failed) report
                | objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ExpertReportObject)
        self.expert_report_objects = com_object

    @property
    def count_fail(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CountFail() As long (Read Only)
                | 
                |     Returns the number of failed tuples in the failed tuples collection. It is
                |     redundant with Collection.Count for ExpertCheckRuntime.Failures collection. For
                |     ExpertCheckRuntime.Succeeds collection, it will fail.
                | 
                |     Example:
                |         This example retrieves in ObjectNumber the number of tuples currently
                |         gathered in MyCollection.
                | 
                |          ObjectNumber = MyCollection.CountFail

        :rtype: int
        """

        return self.expert_report_objects.CountFail

    @property
    def count_succeed(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CountSucceed() As long (Read Only)
                | 
                |     Returns the number of succeeded tuples in the succeeded tuples collection.
                |     It is redundant with Collection.Count for ExpertCheckRuntime.Succeeds
                |     collection. For ExpertCheckRuntime.Failures collection, it will
                |     fail.
                | 
                |     Example:
                |         This example retrieves in ObjectNumber the number of tuples currently
                |         gathered in MyCollection.
                | 
                |          ObjectNumber = MyCollection.CountSucceed

        :rtype: int
        """

        return self.expert_report_objects.CountSucceed

    def fail_item(self, i_index: cat_variant) -> ExpertReportObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FailItem(CATVariant iIndex) As ExpertReportObject
                | 
                |     Retrieves a report failed component from a failed tuples collection, using
                |     its index or its name from the Check collection. It is redundant with
                |     ExpertReportObjects.Item for ExpertCheckRuntime.Failures collections. For
                |     ExpertCheckRuntime.Succeeds collections, it will fail.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Report component to retrieve from the
                |             collection of Report Components. As a numerics, this index is the rank of the
                |             Report component in the collection. The index of the first component in the
                |             collection is 1, and the index of the last component is Count. As a string, it
                |             is the name you assigned to the component using the
                |             
                | 
                |         AnyObject.Name property or when creating the component.
                |         
                |     Returns:
                |         The retrieved Report component

        :param cat_variant i_index:
        :rtype: ExpertReportObject
        """
        return ExpertReportObject(self.expert_report_objects.FailItem(i_index))

    def item(self, i_index: cat_variant) -> ExpertReportObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ExpertReportObject
                | 
                |     Retrieves a Report component using its index or its name from the Check
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                | 
                |             The index or the name of the Report component to retrieve from the
                |             collection of Report Components. As a numerics, this index is the rank of the
                |             Report component in the collection. The index of the first component in the
                |             collection is 1, and the index of the last component is Count. As a string, it
                |             is the name you assigned to the component using the
                |             
                | 
                |         AnyObject.Name property or when creating the
                |         component.
                | 
                |     Returns:
                |         The retrieved Report component

        :param cat_variant i_index:
        :rtype: ExpertReportObject
        """
        return ExpertReportObject(self.expert_report_objects.Item(i_index))

    def succeed_item(self, i_index: cat_variant) -> ExpertReportObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SucceedItem(CATVariant iIndex) As ExpertReportObject
                | 
                |     Retrieves a report component from a succeeded tuples collection, using its
                |     index or its name from the Check collection. It is redundant with
                |     ExpertReportObjects.Item for ExpertCheckRuntime.Succeeds collections. For
                |     ExpertCheckRuntime.Failures collections, it will fail.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Report component to retrieve from the
                |             collection of Report Components. As a numerics, this index is the rank of the
                |             Report component in the collection. The index of the first component in the
                |             collection is 1, and the index of the last component is Count. As a string, it
                |             is the name you assigned to the component using the AnyObject.Name property
                |             or when creating the component.
                |         
                |     Returns:
                |         The retrieved Report component

        :param cat_variant i_index:
        :rtype: ExpertReportObject
        """
        return ExpertReportObject(self.expert_report_objects.SucceedItem(i_index))

    def __repr__(self):
        return f'ExpertReportObjects(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.general_knowledge_interfaces.expert_report_objects import ExpertReportObjects
from pycatia.manufacturing_interfaces.manufacturing_activities import ManufacturingActivities
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.manufacturing_interfaces.manufacturing_operation import ManufacturingOperation


class ManufacturingProgram(ManufacturingActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                        ManufacturingInterfaces.ManufacturingActivity
                |                             ManufacturingProgram
                | 
                | A ManufacturingProgram for a Manufacturing Document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_program = com_object

    @property
    def activities(self) -> ManufacturingActivities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Activities() As MfgActivities (Read Only)
                | 
                |     Give the List of Activities linked to a Manufacturing
                |     Program.
                | 
                |     Example:
                |         The following example returns the list of Activities ActivitiesList
                |         linked to the manufacturing Program CurrentProgram
                | 
                |          Set ActivitiesList = CurrentProgram.Activities

        :rtype: MfgActivities
        """

        return ManufacturingActivities(self.manufacturing_program.Activities)

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR
                | 
                |     Return the Default Comment of a Manufacturing Program.
                | 
                |     Example:
                |         The following example return the comment ProgramComment of to the
                |         manufacturing Program CurrentProgram
                | 
                |          Set CurrentProgram.Comment

        :rtype: str
        """

        return self.manufacturing_program.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_program.Comment = value

    def add_goto_point(self, i_point_name: str) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddGotoPoint(CATBSTR iPointName) As
                | ManufacturingActivity
                | 
                |     Add a Goto Point Operation to a Manufacturing Program.
                | 
                |     Example:
                |         The following example create, inserts and sequences in Program
                |         firstProgram a PTP point instruction GOTO1 to the Point wich alias
                |         isMyPoint
                | 
                |          Set GOTO1 = firstProgram.AddGotoPoint(MyPoint)

        :param str i_point_name:
        :rtype: ManufacturingActivity
        """
        return ManufacturingActivity(self.manufacturing_program.AddGotoPoint(i_point_name))

    def add_goto_point_from_coordinates(self, i_x: float, i_y: float, i_z: float) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddGotoPointfromCoordinates(double iX,
                | double iY,
                | double iZ) As ManufacturingActivity
                | 
                |     Add a Goto Point Operation to a Manufacturing Program.
                | 
                |      The coordinates you give as input for this method have to be expressed
                |      into
                |      the 'Absolute Axis System' not in the 'Machining Axis System' of the Part
                |      Operation.
                | 
                |     Example:
                |         The following example create, inserts and sequences in Program
                |         firstProgram a PTP point instruction GOTO1 to the Point wich coordinates
                |         areX,Y,Z
                | 
                |          Set GOTO1 = firstProgram.AddGotoPointfromCoordinates(X,Y,Z)

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :rtype: ManufacturingActivity
        """
        return ManufacturingActivity(self.manufacturing_program.AddGotoPointfromCoordinates(i_x, i_y, i_z))

    def add_pp_instruction(self, i_pp_instruction: str) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddPPInstruction(CATBSTR iPPInstruction) As
                | ManufacturingActivity
                | 
                |     Add a PP Instruction to a Manufacturing Program.
                | 
                |     Example:
                |         The following example create, inserts and sequences in Program
                |         firstProgram a PP Instruction PPWORD1 with textPPWORD
                | 
                |          Set PPWORD1 = firstProgram.AddPPInstruction(PPWORD)

        :param str i_pp_instruction:
        :rtype: ManufacturingActivity
        """
        return ManufacturingActivity(self.manufacturing_program.AddPPInstruction(i_pp_instruction))

    def add_rotabl(self, i_rotabl: str, i_sens: str, ival: float) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddRotabl(CATBSTR iRotabl,
                | CATBSTR iSens,
                | double ival) As ManufacturingActivity
                | 
                |     Add a Table Head Rotation instruction to a Manufacturing
                |     Program.
                | 
                |     Example:
                |         The following example create, inserts and sequences in Program
                |         firstProgram a Rotabl ROTABL1 with argumentMODE and
                |         angleANGLE1
                | 
                |          Set ROTABL1 = firstProgram.AddRotabl(MODE,ANGLE1)

        :param str i_rotabl:
        :param str i_sens:
        :param float ival:
        :rtype: ManufacturingActivity
        """
        return ManufacturingActivity(self.manufacturing_program.AddRotabl(i_rotabl, i_sens, ival))

    def add_tool_change(
            self,
            i_tool_name: str,
            i_tool_type: str,
            i_tool_catalog: str,
            i_num_syntaxe: int
    ) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddToolChange(CATBSTR iToolName,
                | CATBSTR iToolType,
                | CATBSTR iToolCatalog,
                | short iNumSyntaxe) As ManufacturingActivity
                | 
                |     Add a Tool Change Operation to a Manufacturing Program.
                | 
                |     Example:
                |         The following example create, inserts and sequences in firstProgram a
                |         Tool Change Instruction with specified toolMyTool of specified type ToolTypein
                |         specified catalogToolCatalog
                | 
                |          Set ToolChange1 = firstProgram.AddToolChange(MyTool,ToolType,ToolCatalog,Num)

        :param str i_tool_name:
        :param str i_tool_type:
        :param str i_tool_catalog:
        :param int i_num_syntaxe:
        :rtype: ManufacturingActivity
        """
        return ManufacturingActivity(
            self.manufacturing_program.AddToolChange(
                i_tool_name,
                i_tool_type,
                i_tool_catalog,
                i_num_syntaxe
            )
        )

    def add_tool_change_multiple_feeds(
            self,
            i_tool_name: str,
            i_tool_type: str,
            i_tool_catalog: str,
            i_num_fs_data: int,
            i_num_syntax: int
    ) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddToolChangeMultipleFeeds(CATBSTR iToolName,
                | CATBSTR iToolType,
                | CATBSTR iToolCatalog,
                | short iNumFSData,
                | short iNumSyntaxe) As ManufacturingActivity
                | 
                |     Add a Tool Change Operation to a Manufacturing Program.
                | 
                |     Example:
                |         The following example create, inserts and sequences in firstProgram a
                |         Tool Change Instruction with specified toolMyTool of specified type ToolTypein
                |         specified catalogToolCatalog
                | 
                |          Set ToolChange1 = firstProgram.AddToolChangeMultipleFeeds(MyTool,ToolType,ToolCatalog,NumFSData,Num)

        :param str i_tool_name:
        :param str i_tool_type:
        :param str i_tool_catalog:
        :param int i_num_fs_data:
        :param int i_num_syntax:
        :rtype: ManufacturingActivity
        """
        return ManufacturingActivity(
            self.manufacturing_program.AddToolChangeMultipleFeeds(
                i_tool_name,
                i_tool_type,
                i_tool_catalog,
                i_num_fs_data,
                i_num_syntax
            )
        )

    def append_operation(self, type: str, auto_sequence: int) -> ManufacturingOperation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppendOperation(CATBSTR type,
                | short AutoSequence) As ManufacturingOperation
                | 
                |     Create and Insert a Manufacturing Operation of a specified type to a
                |     Manufacturing Program.
                |     if AutoSequence is set to 1, the new operation will be sequenced in the
                |     Program.
                | 
                |     Example:
                |         The following example creates, inserts and sequences in firstProgram the manufacturing operation ManufacturingOperation of type : type
                | 
                |          Set ManufacturingOperation = firstProgram.AppendOperation(Type,1)

        :param str type:
        :param int auto_sequence:
        :rtype: ManufacturingOperation
        """
        return ManufacturingOperation(self.manufacturing_program.AppendOperation(type, auto_sequence))

    def associate_output_code(self, i_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AssociateOutputCode(CATBSTR iFileName)
                | 
                |     Method is used for associate APT file to V4 program iFileName = path for APT file.... Call on V4 ManufacturingProgram

        :param str i_file_name:
        :rtype: None
        """
        return self.manufacturing_program.AssociateOutputCode(i_file_name)

    def complete_with_polar_strategy(
            self,
            i_liste_mfg_activity: ManufacturingActivities,
            i_axe_ref: str,
            i_sens_rotation: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CompletewithPolarStrategy(MfgActivities
                | iListeMfgActivity,
                | CATBSTR iAxeRef,
                | CATBSTR iSensRotation)
                | 
                |     Complete a list of Operation in a Manufacturing Program in Polar
                |     Mode.
                | 
                |     Example:
                |         The following example complete in Program firstProgram a liste of
                |         Operation ListeMo with Reference Axis A and sens CLW
                | 
                |          Call
                |          firstProgram.CompletewithPolarStrategy(ListeMo,A,CLW)

        :param MfgActivities i_liste_mfg_activity:
        :param str i_axe_ref:
        :param str i_sens_rotation:
        :rtype: None
        """
        return self.manufacturing_program.CompletewithPolarStrategy(
            i_liste_mfg_activity.com_object,
            i_axe_ref,
            i_sens_rotation)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'completewith_polar_strategy'
        # # vba_code = """
        # # Public Function completewith_polar_strategy(manufacturing_program)
        # #     Dim iListeMfgActivity (2)
        # #     manufacturing_program.CompletewithPolarStrategy iListeMfgActivity
        # #     completewith_polar_strategy = iListeMfgActivity
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_mo_from_report(self, i_report_succeed: ExpertReportObjects, i_type_mo: str) -> ManufacturingActivities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateMOfromReport(ExpertReportObjects
                | iReportSucceed,
                | CATBSTR iTypeMo) As MfgActivities
                | 
                |     Create a list of Operation in a Manufacturing Program, of a specified
                |     type.
                | 
                |     Example:
                |         The following example create in Program firstProgram a liste of
                |         Operation ListeMo with type Drilling from a CATIAExpertReportSucceedCollection
                |         ReportSucceed.
                | 
                |          Set ListeMO = firstProgram.CreateMOfromReport(ReportSucceed,Drilling)

        :param ExpertReportObjects i_report_succeed:
        :param str i_type_mo:
        :rtype: MfgActivities
        """
        return ManufacturingActivities(
            self.manufacturing_program.CreateMOfromReport(i_report_succeed.com_object, i_type_mo))

    def get_nc_output_file(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNCOutputFile() As CATBSTR
                | 
                |     Get the output file (APT or ISO) associated to the program (if associated
                |     during computation).

        :rtype: str
        """
        return self.manufacturing_program.GetNCOutputFile()

    def get_table_current_absolute_position(self, i_activity_ref: ManufacturingActivity) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTableCurrentAbsolutePosition(ManufacturingActivity iActivityRef) As
                | double
                | 
                |     Get the current absolute position of the Machine Table.
                | 
                |     Example:
                |         The following example gets in Program firstProgram the current Machine
                |         Table absolute position Angle from the Manufacturing activity reference
                |         iActivityRef
                | 
                |          Angle = firstProgram.GetTableCurrentAbsolutePosition(iActivityRef)

        :param ManufacturingActivity i_activity_ref:
        :rtype: float
        """
        return self.manufacturing_program.GetTableCurrentAbsolutePosition(i_activity_ref.com_object)

    def import_nc_output_on_program(self, i_type: str, i_nc_output_file: str, i_pp_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportNCOutputOnProgram(CATBSTR iType,
                | CATBSTR iNCOutputFile,
                | CATBSTR iPPName)
                | 
                |     Import an NC File on a program.
                | 
                |     Example:
                |         The following example imports in a Program firstProgram an NC File of
                |         type TYPE available in the file path PATH using the PP PPNAME if
                |         required.
                | 
                |          Call firstProgram.ImportNCOutputOnProgram(TYPE,PATH,PPNAME)

        :param str i_type:
        :param str i_nc_output_file:
        :param str i_pp_name:
        :rtype: None
        """
        return self.manufacturing_program.ImportNCOutputOnProgram(i_type, i_nc_output_file, i_pp_name)

    def insert_operation(
            self,
            i_reference_operation: ManufacturingOperation,
            i_manufacturing_operation: ManufacturingOperation
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InsertOperation(ManufacturingOperation
                | iReferenceOperation,
                | ManufacturingOperation iManufacturingOperation)
                | 
                |     Insert an existing Manufacturing Operation to a Manufacturing
                |     Program.
                | 
                |     Example:
                |         The following example inserts in firstProgram the manufacturing
                |         operation ExistingOperation after ReferenceOperation:
                | 
                |          call firstProgram.InsertOperation(ReferenceOperation,ExistingOperation)

        :param ManufacturingOperation i_reference_operation:
        :param ManufacturingOperation i_manufacturing_operation:
        :rtype: None
        """
        return self.manufacturing_program.InsertOperation(
            i_reference_operation.com_object,
            i_manufacturing_operation.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_operation'
        # # vba_code = """
        # # Public Function insert_operation(manufacturing_program)
        # #     Dim iReferenceOperation (2)
        # #     manufacturing_program.InsertOperation iReferenceOperation
        # #     insert_operation = iReferenceOperation
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def lock_activities_within_program(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LockActivitesWithinProgram()
                | 
                |     Method is used for Locking and Unloking all activity in program Call on
                |     ManufacturingProgram on which Lock and Unlock want

        :rtype: None
        """
        return self.manufacturing_program.LockActivitesWithinProgram()

    def move_operation(
            self,
            i_reference_operation: ManufacturingActivity,
            i_manufacturing_operation: ManufacturingActivity
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub MoveOperation(ManufacturingActivity
                | iReferenceOperation,
                | ManufacturingActivity iManufacturingOperation)
                | 
                |     Move an existing Manufacturing Operation to a Manufacturing
                |     Program.
                | 
                |     Example:
                |         The following example moves in firstProgram the manufacturing operation
                |         MovedOperation after the manufacturing
                |         operationExistingOperation:
                | 
                |          call firstProgram.MoveOperation(ExistingOperation,
                |          MovedOperation)

        :param ManufacturingActivity i_reference_operation:
        :param ManufacturingActivity i_manufacturing_operation:
        :rtype: None
        """
        return self.manufacturing_program.MoveOperation(
            i_reference_operation.com_object,
            i_manufacturing_operation.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'move_operation'
        # # vba_code = """
        # # Public Function move_operation(manufacturing_program)
        # #     Dim iReferenceOperation (2)
        # #     manufacturing_program.MoveOperation iReferenceOperation
        # #     move_operation = iReferenceOperation
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def order_and_create_mo_from_report(
            self,
            i_report_succeed: ExpertReportObjects,
            i_type_mo: str,
            i_axe_rotabl: str,
            i_sens_rotation: str
    ) -> ManufacturingActivities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func OrderAndCreateMOfromReport(ExpertReportObjects
                | iReportSucceed,
                | CATBSTR iTypeMo,
                | CATBSTR iAxeRotabl,
                | CATBSTR iSensRotation) As MfgActivities
                | 
                |     Create a list of Operation in a Manufacturing Program, of a specified
                |     type.
                | 
                |     Example:
                |         The following example create in Program firstProgram a liste of
                |         Operation ListeMo with type Drilling from a CATIAExpertReportSucceedCollection
                |         ReportSucceed with Rotabl of Axis A and sens CLW.
                | 
                |          Set ListeMO = firstProgram.OrderAndCreateMOfromReport(ReportSucceed,Drilling)

        :param ExpertReportObjects i_report_succeed:
        :param str i_type_mo:
        :param str i_axe_rotabl:
        :param str i_sens_rotation:
        :rtype: MfgActivities
        """
        return ManufacturingActivities(
            self.manufacturing_program.OrderAndCreateMOfromReport(
                i_report_succeed.com_object,
                i_type_mo,
                i_axe_rotabl,
                i_sens_rotation
            )
        )

    def unlock_activities_within_program(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnlockActivitesWithinProgram()

        :rtype: None
        """
        return self.manufacturing_program.UnlockActivitesWithinProgram()

    def __repr__(self):
        return f'ManufacturingProgram(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity


class GenericAction(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         GenericAction
                | 
                | Interface representing a GenericAction.
                | 
                | Role: This interface is used to work with GenericAction which consists of a
                | predefined list of Atomic activities.
                | The following code snippet can be used to obtain a GenericAction from a
                | selected Activity
                | 
                |    Dim oSelectAct As Activity
                |    set oSelectAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |    Dim objGenAction As GenericAction
                |    set objGenAction = oSelectAct.GetTechnologicalObject("GenericAction")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.generic_action = com_object

    def get_atomic_activities(self, o_atomic_activities: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAtomicActivities(CATSafeArrayVariant
                | oAtomicActivities)
                | 
                |     Retreives the list of Atomic activities for the action.
                | 
                |     Parameters:
                | 
                |         oAtomicActivities
                |             The List of Atomic activities. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             List of Atomic activities is successfully returned
                |         E_FAIL
                |             List of Atomic activities could not be obtained
                | 
                |     Example:
                |
                |            Dim objGenAct As GenericAction
                |                   ......
                |            Dim List() 
                |            set List = objGenAct.GetAtomicActivities
                |            ..

        :param tuple o_atomic_activities:
        :rtype: None
        """
        return self.generic_action.GetAtomicActivities(o_atomic_activities)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_atomic_activities'
        # # vba_code = """
        # # Public Function get_atomic_activities(generic_action)
        # #     Dim oAtomicActivities (2)
        # #     generic_action.GetAtomicActivities oAtomicActivities
        # #     get_atomic_activities = oAtomicActivities
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'GenericAction(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_manikin_part import SWKManikinPart


class SWKDOF(SWKManikinPart):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKManikinPart
                |                         SWKDOF
                | 
                | This interface deals with a degree of freedom (DOF) of a
                | manikin.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swkdof = com_object

    @property
    def default_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DefaultValue() As double (Read Only)
                | 
                |     Returns the default value of a DOF. The value read is always in radians.

        :rtype: float
        """

        return self.swkdof.DefaultValue

    @property
    def full_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FullName() As CATBSTR (Read Only)
                | 
                |     Returns the full name of the degree of freedom (e.g.
                |     "flexion/extension").
                |     This property is different from the property Name of
                |     AnyObject, which gives the short name or abbreviated name
                |     of the DOF (e.g. "DOF1").

        :rtype: str
        """

        return self.swkdof.FullName

    @property
    def limits_locked(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LimitsLocked() As boolean
                | 
                |     Sets a lock on the limits.
                |     When the value of this property is TRUE, the DOF travel limits are locked,
                |     therefore the min and max values cannot be changed.
                |     When the value is FALSE, the DOF limits are unlocked and can be changed. By
                |     default, the DOF limits are locked and the application must unlock these limits
                |     before changing them.

        :rtype: bool
        """

        return self.swkdof.LimitsLocked

    @limits_locked.setter
    def limits_locked(self, value: bool):
        """
        :param bool value:
        """

        self.swkdof.LimitsLocked = value

    @property
    def max_mean(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxMean() As double (Read Only)
                | 
                |     Returns the mean value of the upper limit of the DOF (in
                |     radians).

        :rtype: float
        """

        return self.swkdof.MaxMean

    @property
    def max_mean_inter_segment(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxMeanInterSegment() As double (Read Only)

        :rtype: float
        """

        return self.swkdof.MaxMeanInterSegment

    @property
    def max_score(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxScore() As double (Read Only)
                | 
                |     Returns the highest score that this DOF can take.

        :rtype: float
        """

        return self.swkdof.MaxScore

    @property
    def max_std_dev(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxStdDev() As double (Read Only)
                | 
                |     Returns the standard deviation value of the upper limit of the DOF (in
                |     radians).

        :rtype: float
        """

        return self.swkdof.MaxStdDev

    @property
    def max_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxValue() As double
                | 
                |     Returns or sets the highest value that a DOF can take.
                |     When setting the value, the new value given
                |     cannot be higher than the statistical value found
                |     in the limits database. This statistical maximum
                |     value can be obtained by a call to property
                |     StatisticalMaxValue.

        :rtype: float
        """

        return self.swkdof.MaxValue

    @max_value.setter
    def max_value(self, value: float):
        """
        :param float value:
        """

        self.swkdof.MaxValue = value

    @property
    def max_value_as_percentile(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxValueAsPercentile() As double
                | 
                |     Returns or sets the highest value that a DOF can take.
                |     When reading the value, the number returned
                |     will take a percentile format, that is, will
                |     be between 0.0 and 100.0 inclusive.
                | 
                |     When setting the value, the new value given
                |     must also lie in the range [ 0.0 ; 100.0 ].

        :rtype: float
        """

        return self.swkdof.MaxValueAsPercentile

    @max_value_as_percentile.setter
    def max_value_as_percentile(self, value: float):
        """
        :param float value:
        """

        self.swkdof.MaxValueAsPercentile = value

    @property
    def min_mean(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinMean() As double (Read Only)
                | 
                |     Returns the mean value of the lower limit of the DOF (in
                |     radians).

        :rtype: float
        """

        return self.swkdof.MinMean

    @property
    def min_mean_inter_segment(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinMeanInterSegment() As double (Read Only)

        :rtype: float
        """

        return self.swkdof.MinMeanInterSegment

    @property
    def min_std_dev(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinStdDev() As double (Read Only)
                | 
                |     Returns the standard deviation value of the lower limit of
                |     the DOF (in radians).

        :rtype: float
        """

        return self.swkdof.MinStdDev

    @property
    def min_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinValue() As double
                | 
                |     Returns or sets the lowest value that a DOF can take.
                |     When setting the value, the new value given
                |     cannot be lower than the statistical value found
                |     in the limits database. This statistical minimum
                |     value can be obtained by a call to property
                |     StatisticalMinValue.

        :rtype: float
        """

        return self.swkdof.MinValue

    @min_value.setter
    def min_value(self, value: float):
        """
        :param float value:
        """

        self.swkdof.MinValue = value

    @property
    def min_value_as_percentile(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinValueAsPercentile() As double
                | 
                |     Returns or sets the lowest value that a DOF can take.
                |     When reading the value, the number returned
                |     will take a percentile format, that is, will
                |     be between 0.0 and 100.0 exclusive.
                | 
                |     When setting the value, the new value given
                |     must also lie in the range [ 0.0 ; 100.0 ].

        :rtype: float
        """

        return self.swkdof.MinValueAsPercentile

    @min_value_as_percentile.setter
    def min_value_as_percentile(self, value: float):
        """
        :param float value:
        """

        self.swkdof.MinValueAsPercentile = value

    @property
    def min_value_inter_segment(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinValueInterSegment() As double (Read Only)

        :rtype: float
        """

        return self.swkdof.MinValueInterSegment

    @property
    def number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Number() As long (Read Only)
                | 
                |     Returns the number of the DOF. This number is an integer between 0 and
                |     2.
                | 
                |     See also:
                |         SWKSegment

        :rtype: int
        """

        return self.swkdof.Number

    @property
    def score(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Score() As double (Read Only)
                | 
                |     Returns the score corresponding to the DOF's current value.

        :rtype: float
        """

        return self.swkdof.Score

    @property
    def value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Value() As double
                | 
                |     Returns or sets the value of a DOF.
                |     The value read or set is always in radians.

        :rtype: float
        """

        return self.swkdof.Value

    @value.setter
    def value(self, value: float):
        """
        :param float value:
        """

        self.swkdof.Value = value

    @property
    def value_as_string(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ValueAsString() As CATBSTR
                | 
                |     Returns or sets the value of a DOF, as a string.
                | 
                |     Example:
                | 
                |           myManikin.Body.GetSegment("LSLeTh").
                |          ValueAsString = "10deg"

        :rtype: str
        """

        return self.swkdof.ValueAsString

    @value_as_string.setter
    def value_as_string(self, value: str):
        """
        :param str value:
        """

        self.swkdof.ValueAsString = value

    @property
    def value_locked(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ValueLocked() As boolean
                | 
                |     Sets a lock on the value.
                |     When the value of this property is TRUE, the DOF's current value is locked
                |     and cannot be changed.
                |     When this property is set to FALSE, the DOF value is unlocked and can be
                |     changed again. Locking a value on a DOF means that this DOF will ne take any
                |     other value than the current one, and will not be changed by an inverse
                |     kinematics resolution, for instance.

        :rtype: bool
        """

        return self.swkdof.ValueLocked

    @value_locked.setter
    def value_locked(self, value: bool):
        """
        :param bool value:
        """

        self.swkdof.ValueLocked = value

    def reset_value(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetValue()
                | 
                |     Sets the value of the DOF to its default value.

        :rtype: None
        """
        return self.swkdof.ResetValue()

    def set_limits_to_match_best_pref_angle(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLimitsToMatchBestPrefAngle()
                | 
                |     Set the angular limitations to match with the best pref angle. The purpose
                |     of this method is to set the angular limitations of this DOF so that these
                |     limitations correspond to the best range of motion, that is, the range of
                |     motion where the postural score is the highest.
                | 
                |     This method travels the different preferred angles on the DOF, then chooses
                |     the one with the highest score. If several preferred angles are found with the
                |     highest score, then the last one with the highest score is
                |     taken.
                | 
                |     If no preferred angles have been defined on this DOF, then the angular
                |     limitations are not modified.

        :rtype: None
        """
        return self.swkdof.SetLimitsToMatchBestPrefAngle()

    def __repr__(self):
        return f'SWKdof(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.item import Item
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class MfgAssembly(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MfgAssembly
                | 
                | This Interface represents a Manufacturing Assembly.
                | Role: It gives access to the C++ DNBIMfgAssembly interface methods Such
                | as
                | 
                |     set and get the Name and PartNumber
                |     get the type DNBIAMfgAssemblyType
                |     get the assigned parts
                |     add and remove the assigned parts
                | 
                | Example:
                |     This example fetches an instance of a Manufacturing Assembly from a
                |     selected Activity
                | 
                |      Dim myActivity As Activity
                |      myActivity = 
                |      Dim myItem As Item
                |      Set myItem = myActivity.Items.Item(1)
                |      Dim obj As MfgAssembly
                |      Set obj = mySel.FindObject("DNBIAMfgAssembly")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mfg_assembly = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the number of assigned Parts (can be fetched via Item
                |     ).
                | 
                |     Example:
                |         This example fetches the Number of assigned Parts of a Manufacturing
                |         Assembly
                | 
                |          Dim Number As Long
                |          Number = obj.Count

        :rtype: int
        """

        return self.mfg_assembly.Count

    @property
    def ma_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MAName() As CATBSTR
                | 
                |     Returns or sets the Name of the Manufacturing Assembly. Name of the AST
                |     Manufacturing Assembly cannot be set/changed
                | 
                |     Example:
                |         This example fetches the Name of a Manufacturing
                |         Assembly
                | 
                |          Dim myName As String
                |          myName = obj.MAName
                |          
                | 
                |         This example sets the Name of a Manufacturing Assembly
                | 
                |          Dim newName As String
                |          newName = "NewMAName"
                |          obj.MAName = newName

        :rtype: str
        """

        return self.mfg_assembly.MAName

    @ma_name.setter
    def ma_name(self, value: str):
        """
        :param str value:
        """

        self.mfg_assembly.MAName = value

    @property
    def ma_part_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MAPartNumber() As CATBSTR
                | 
                |     Returns or sets the Part Number of the Manufacturing Assembly. Part Number
                |     of the AST MA cannot be set/changed
                | 
                |     Example:
                |         This example fetches the Part Number of a Manufacturing
                |         Assembly
                | 
                |          Dim myPart As String
                |          myPart = obj.MAPartNumber
                |
                |         This example sets the Part Number of a Manufacturing
                |         Assembly
                | 
                |          Dim newPartNbr As String
                |          newPartNbr = "NewMAPartNumber"
                |          obj.MAPartNumber = newPartNbr

        :rtype: str
        """

        return self.mfg_assembly.MAPartNumber

    @ma_part_number.setter
    def ma_part_number(self, value: str):
        """
        :param str value:
        """

        self.mfg_assembly.MAPartNumber = value

    @property
    def ma_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MAType() As DNBIAMfgAssemblyType (Read Only)
                | 
                |     Returns the Type of the Manufacturing Assembly. It will be either a
                |     manufacturingAssembly or a manufacturingKit defined in
                |     DNBIAMfgAssemblyType
                | 
                |     Example:
                |         This example fetches the Type of a Manufacturing
                |         Assembly
                | 
                |          Dim MAtype As String
                |          If obj.MAType = manufacturingAssembly Then
                |            MAtype = "Manufacturing Assembly"
                |          Else
                |            MAtype = "Manufacturing Kit"
                |          End If

        :return: enum dnbia_mfg_assembly_type
        :rtype: int
        """

        return self.mfg_assembly.MAType

    def add_part(self, i_item: Item) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPart(Item iItem)
                | 
                |     Assignes a part (Product, Resource or other MA/MK) to the Manufacturing
                |     Assembly. No part can be assigned to AST MA
                | 
                |     Parameters:
                | 
                |         iItem
                |             The item to be assigned
                | 
                |             Example:
                |                 This example adds a product to the assigned Parts of a
                |                 Manufacturing Assembly
                | 
                |                  Dim myProducts As PPRProducts
                |                  Set myProducts = DELMIA.ActiveDocument.PPRDocument.Products
                |                  Dim Part As Item
                |                  Set Part = myProducts.Item(2)
                |                  obj.AddPart(Part)

        :param Item i_item:
        :rtype: None
        """
        return self.mfg_assembly.AddPart(i_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_part'
        # # vba_code = """
        # # Public Function add_part(mfg_assembly)
        # #     Dim iItem (2)
        # #     mfg_assembly.AddPart iItem
        # #     add_part = iItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def item(self, i_index: cat_variant) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Item
                | 
                |     Returns one assigned Part (Product, Resource or other MA/MK) of the
                |     Manufacturing Assembly.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index to the item to be returned 
                | 
                |     Returns:
                |         The assigned item
                | 
                |         Example:
                |             This example cycles through the list of assigned Parts of a
                |             Manufacturing Assembly
                | 
                |              Dim j As Long
                |              For j = 1 To obj.Count
                |                Dim it As Item
                |                Set it = obj.Item(j)
                |                Dim ItemName As String
                |                ItemName = it.Name
                |              Next

        :param cat_variant i_index:
        :rtype: Item
        """
        return Item(self.mfg_assembly.Item(i_index))

    def remove_part(self, i_item: Item) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePart(Item iItem)
                | 
                |     Removes a part (Product, Resource or other MA/MK) from the Manufacturing
                |     Assembly. No part can be removed from AST MA
                | 
                |     Parameters:
                | 
                |         iItem
                |             The item to be removed
                | 
                |             Example:
                |                 This example removes a product from the assigned Parts of a
                |                 Manufacturing Assembly
                | 
                |                  Dim myProducts As PPRProducts
                |                  Set myProducts = DELMIA.ActiveDocument.PPRDocument.Products
                |                  Dim Part As Item
                |                  Set Part = myProducts.Item(2)
                |                  obj.RemovePart(Part)

        :param Item i_item:
        :rtype: None
        """
        return self.mfg_assembly.RemovePart(i_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_part'
        # # vba_code = """
        # # Public Function remove_part(mfg_assembly)
        # #     Dim iItem (2)
        # #     mfg_assembly.RemovePart iItem
        # #     remove_part = iItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MfgAssembly(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.product_structure_interfaces.product import Product


class ReleaseAct(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         ReleaseAct
                | 
                | Interface representing a Release activity.
                | 
                | Role: This interface is used to retrieve/assign the value of attributes for the
                | Release activity.
                | The following code snippet can be used to obtain a ReleaseAct from a selected
                | Activity
                | 
                |    Dim oSelectAct As Activity
                |    set oSelectAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |    Dim objReleaseAct As ReleaseAct
                |    set objReleaseAct = oSelectAct.GetTechnologicalObject("ReleaseAct")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.release_act = com_object

    @property
    def grabbing_object(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GrabbingObject() As Product
                | 
                |     Sets and retrieves the grabbing object
                | 
                |     Returns:
                |         oGrabbingObject The grabbing object. 
                |     Parameters:
                | 
                |         iGrabbingObject
                |             The specified grabbing object

        :rtype: Product
        """

        return Product(self.release_act.GrabbingObject)

    @grabbing_object.setter
    def grabbing_object(self, value: Product):
        """
        :param Product value:
        """

        self.release_act.GrabbingObject = value

    def get_grabbed_objects(self, o_grabbed_objects: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGrabbedObjects(CATSafeArrayVariant oGrabbedObjects)
                | 
                |     Sets and retrieves the grabbed objects
                | 
                |     Returns:
                |         oGrabbedObjects The grabbed object. 
                |     Parameters:
                | 
                |         iGrabbedObjects
                |             The specified grabbed objects

        :param tuple o_grabbed_objects:
        :rtype: None
        """
        return self.release_act.GetGrabbedObjects(o_grabbed_objects)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_grabbed_objects'
        # # vba_code = """
        # # Public Function get_grabbed_objects(release_act)
        # #     Dim oGrabbedObjects (2)
        # #     release_act.GetGrabbedObjects oGrabbedObjects
        # #     get_grabbed_objects = oGrabbedObjects
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_grabbed_objects(self, i_grabbed_objects: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutGrabbedObjects(CATSafeArrayVariant iGrabbedObjects)

        :param tuple i_grabbed_objects:
        :rtype: None
        """
        return self.release_act.PutGrabbedObjects(i_grabbed_objects)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_grabbed_objects'
        # # vba_code = """
        # # Public Function put_grabbed_objects(release_act)
        # #     Dim iGrabbedObjects (2)
        # #     release_act.PutGrabbedObjects iGrabbedObjects
        # #     put_grabbed_objects = iGrabbedObjects
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ReleaseAct(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPApplication(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspApplication
                | 
                | Represents an application.
                | Role: To activate and query a Distributive System application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_application = com_object

    def initialization(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Initialization()
                | 
                |     Initializes the application environment (load feature start up objects,
                |     activate the application..).
                | 
                |     Example:
                |
                |          Dim objPrdRoot        As Product
                |          Dim objPspWorkbench   As PspWorkbench
                |          Dim objPspApplnPip       As PspApplication
                |          Dim objPspApplnTub    As PspApplication
                | 
                |          Set objPrdRoot = CATIA.ActiveDocument.Product
                |          Set objPspWorkbench = objPrdRoot.GetTechnologicalObject ("PspWorkbench")
                |          
                |          Set objPspApplnPip = objPspWorkbench.GetApplication(catPspIDLCATPiping)
                |          ...
                |          objPspApplnPip.Initialization
                |          ....
                |          Set objPspApplnTub = objPspWorkbench.GetApplication(catPspIDLCATTubing)

        :rtype: None
        """
        return self.psp_application.Initialization()

    def __repr__(self):
        return f'PSPApplication(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_nodes import ArrangementNodes
from pycatia.system_interfaces.any_object import AnyObject


class ArrangementRun(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrangementRun
                | 
                | Use this object to access the properties and methods of an ArrangementRun
                | object.
                | Role: Use this interface to control the visualization mode, section parameters,
                | nodes that define the ArrangementRun object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arrangement_run = com_object

    @property
    def arrangement_nodes(self) -> ArrangementNodes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementNodes() As ArrangementNodes (Read Only)
                | 
                |     Returns the ArrangementNodes that make up the
                |     ArrangementRun.
                | 
                |     Example:
                |         This example gets the ArrangementNodes for the objRun1
                |         object.
                | 
                |          Dim objArrNodes   As ArrangementNodes
                |          Set objArrNodes = objRun1.ArrangementNodes

        :rtype: ArrangementNodes
        """

        return ArrangementNodes(self.arrangement_run.ArrangementNodes)

    @property
    def length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Length() As double (Read Only)
                | 
                |     Returns the length of the ArrangementRun object.
                | 
                |     Example:
                |         This example retrieves the Length of the objRun1
                |         object.
                | 
                |          Dim dblLength   As Double
                |          dblLength  = objRun1.Length

        :rtype: float
        """

        return self.arrangement_run.Length

    @property
    def section_diameter(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionDiameter() As double
                | 
                |     Returns or sets the SectionDiameter for an ArrangementRun
                |     object.
                | 
                |     Example:
                |         This example retrieves the SectionDiameter for the objRun1
                |         object.
                | 
                |          Dim dblSectionDia   As Double
                |          dblSectionDia = objRun1.SectionDiameter

        :rtype: float
        """

        return self.arrangement_run.SectionDiameter

    @section_diameter.setter
    def section_diameter(self, value: float):
        """
        :param float value:
        """

        self.arrangement_run.SectionDiameter = value

    @property
    def section_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionHeight() As double
                | 
                |     Returns or sets the SectionHeight for an ArrangementRun
                |     object.
                | 
                |     Example:
                |         This example gets the SectionHeight for the objRun1
                |         object.
                | 
                |          Dim dblSectionHeight   As Double
                |          dblSectionHeight = objRun1.SectionHeight

        :rtype: float
        """

        return self.arrangement_run.SectionHeight

    @section_height.setter
    def section_height(self, value: float):
        """
        :param float value:
        """

        self.arrangement_run.SectionHeight = value

    @property
    def section_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionType() As CATArrangementRouteSection
                | 
                |     Returns or sets the SectionType for an ArrangementRun
                |     object.
                | 
                |     Example:
                |         This example sets the SectionType for the objRun1 object to
                |         CatArrangementRouteSectionRectangular.
                | 
                |          objRun1.SectionType = CatArrangementRouteSectionRectangular

        :rtype: int
        """

        return self.arrangement_run.SectionType

    @section_type.setter
    def section_type(self, value: int):
        """
        :param int value:
        """

        self.arrangement_run.SectionType = value

    @property
    def section_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionWidth() As double
                | 
                |     Returns or sets the SectionWidth for an ArrangementRun
                |     object.
                | 
                |     Example:
                |         This example gets the SectionWidth for the objRun1
                |         object.
                | 
                |          Dim dblSectionWidth   As Double
                |          dblSectionWidth = objRun1.SectionWidth

        :rtype: float
        """

        return self.arrangement_run.SectionWidth

    @section_width.setter
    def section_width(self, value: float):
        """
        :param float value:
        """

        self.arrangement_run.SectionWidth = value

    @property
    def visu_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuMode() As CATArrangementRouteVisuMode
                | 
                |     Returns or sets the Visualization Mode for an ArrangementRun
                |     object.
                | 
                |     Example:
                |         This example sets the Visualization Mode for the objRun1 object to
                |         CatArrangementRouteVisuModeSolid.
                | 
                |          objRun1.VisuMode = CatArrangementRouteVisuModeSolid

        :return: enum cat_arrangement_route_visu_mode
        :rtype: int
        """

        return self.arrangement_run.VisuMode

    @visu_mode.setter
    def visu_mode(self, value: int):
        """
        :param int value: enum cat_arrangement_route_visu_mode
        """

        self.arrangement_run.VisuMode = value

    def get_technological_object(self, i_application_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTechnologicalObject(CATBSTR iApplicationType) As
                | CATBaseDispatch
                | 
                |     Returns the applicative data which type is the given
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iApplicationType
                |             The type of applicative data searched. 
                |         oApplicativeObj
                |             The matched applicative object.
                | 
                |             Example:
                |                 This example retrieves the desired applicative object from the
                |                 objRun1 object.
                | 
                |                  Dim objProd   As Product
                |                  objProd  = objRun1.GetTechnologicalObject("Product")

        :param str i_application_type:
        :rtype: AnyObject
        """
        return self.arrangement_run.GetTechnologicalObject(i_application_type)

    def __repr__(self):
        return f'ArrangementRun(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_generator_data import ManufacturingGeneratorData
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingOutputGenerator(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingOutputGenerator
                | 
                | Father object to generate output machining code.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_output_generator = com_object

    def add_me_to_buffer(self, o_add_me: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMeToBuffer(long oAddMe)
                | 
                |     Management of specific buffer for aligned points elimination.

        :param int o_add_me:
        :rtype: None
        """
        return self.manufacturing_output_generator.AddMeToBuffer(o_add_me)

    def generate_output_code(self, i_data: ManufacturingGeneratorData) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GenerateOutputCode(ManufacturingGeneratorData iData)
                | 
                |     Return the Output Code for an object in the right CNC Machine.

        :param ManufacturingGeneratorData i_data:
        :rtype: None
        """
        return self.manufacturing_output_generator.GenerateOutputCode(i_data.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'generate_output_code'
        # # vba_code = """
        # # Public Function generate_output_code(manufacturing_output_generator)
        # #     Dim iData (2)
        # #     manufacturing_output_generator.GenerateOutputCode iData
        # #     generate_output_code = iData
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_apt_code(self, i_data: ManufacturingGeneratorData, o_code: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAPTCode(ManufacturingGeneratorData iData,
                | CATBSTR oCode)
                | 
                |     Retrieve generated APT code.

        :param ManufacturingGeneratorData i_data:
        :param str o_code:
        :rtype: None
        """
        return self.manufacturing_output_generator.GetAPTCode(i_data.com_object, o_code)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_apt_code'
        # # vba_code = """
        # # Public Function get_apt_code(manufacturing_output_generator)
        # #     Dim iData (2)
        # #     manufacturing_output_generator.GetAPTCode iData
        # #     get_apt_code = iData
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_current_object(self, o_current_object: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCurrentObject(long oCurrentObject)
                | 
                |     Get current object from buffer.

        :param int o_current_object:
        :rtype: None
        """
        return self.manufacturing_output_generator.GetCurrentObject(o_current_object)

    def has_to_reset_modal_values(self, o_is_modal: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub HasToResetModalValues(long oIsModal)
                | 
                |     Return the characteristic of an object : Reset or not Modal Values.

        :param int o_is_modal:
        :rtype: None
        """
        return self.manufacturing_output_generator.HasToResetModalValues(o_is_modal)

    def init_file_generator(self, i_format: str, i_file_name: str, o_data: ManufacturingGeneratorData) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InitFileGenerator(CATBSTR iFormat,
                | CATBSTR iFileName,
                | ManufacturingGeneratorData oData)
                | 
                |     Init the Output Generator on the current Object and initialise all datas.
                |     Generation of NC code can start from the Process, Setup, Program or an
                |     Activity.
                | 
                |     Parameters:
                | 
                |         iFormat
                |             Format of the output file : "APT", ... 
                |         iFileName
                |             Output file name 
                |         oData
                |             iData contains all the information about the generated NC
                |             code

        :param str i_format:
        :param str i_file_name:
        :param ManufacturingGeneratorData o_data:
        :rtype: None
        """
        return self.manufacturing_output_generator.InitFileGenerator(i_format, i_file_name, o_data.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'init_file_generator'
        # # vba_code = """
        # # Public Function init_file_generator(manufacturing_output_generator)
        # #     Dim iFormat (2)
        # #     manufacturing_output_generator.InitFileGenerator iFormat
        # #     init_file_generator = iFormat
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_modal(self, o_is_modal: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsModal(long oIsModal)
                | 
                |     Return the characteristic of an object : Modal or Not Modal.

        :param int o_is_modal:
        :rtype: None
        """
        return self.manufacturing_output_generator.IsModal(o_is_modal)

    def is_similar_to(self, i_object: 'ManufacturingOutputGenerator') -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsSimilarTo(ManufacturingOutputGenerator iObject) As
                | long
                | 
                |     Implement a method to specify if two objects are same (when Modal Mode).
                |     The result depends on the tolerance on the values (to points)

        :param ManufacturingOutputGenerator i_object:
        :rtype: int
        """
        return self.manufacturing_output_generator.IsSimilarTo(i_object.com_object)

    def run_file_generator(self, i_data: ManufacturingGeneratorData) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RunFileGenerator(ManufacturingGeneratorData iData)
                | 
                |     Runs the Output Generator on the datas used for generation. Generation of
                |     NC code can start from the Process, Setup, Program or an
                |     Activity.
                | 
                |     Parameters:
                | 
                |         iData
                |             iData contains all the information about the generated NC
                |             code

        :param ManufacturingGeneratorData i_data:
        :rtype: None
        """
        return self.manufacturing_output_generator.RunFileGenerator(i_data.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'run_file_generator'
        # # vba_code = """
        # # Public Function run_file_generator(manufacturing_output_generator)
        # #     Dim iData (2)
        # #     manufacturing_output_generator.RunFileGenerator iData
        # #     run_file_generator = iData
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_current_object(self, i_current_object: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentObject(long iCurrentObject)
                | 
                |     Set current object to buffer.

        :param int i_current_object:
        :rtype: None
        """
        return self.manufacturing_output_generator.SetCurrentObject(i_current_object)

    def __repr__(self):
        return f'ManufacturingOutputGenerator(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class MechanismCommand(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MechanismCommand
                | 
                | Interface to access the Command object (in Kinematics
                | context).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mechanism_command = com_object

    @property
    def current_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CurrentValue() As double (Read Only)
                | 
                |     Returns the current value for a command.
                | 
                |     Parameters:
                | 
                |         oCurrentValue
                |             The current value This property is read only because current value
                |             modification is done by solver

        :rtype: float
        """

        return self.mechanism_command.CurrentValue

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Orientation() As short
                | 
                |     Deprecated:
                |         V5R18 Not implemented - will be deprecated Returns or sets the command
                |         orientation. 
                |     Parameters:
                | 
                |         oOrientation
                |             The orientation of the command; only the sign is important (+: same
                |             as relying joint/-: opposite)

        :rtype: int
        """

        return self.mechanism_command.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.mechanism_command.Orientation = value

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the command type.
                | 
                |     Parameters:
                | 
                |         oType
                |             The type of the command 
                | 
                |     See also:
                |         Mechanism

        :rtype: str
        """

        return self.mechanism_command.Type

    def __repr__(self):
        return f'MechanismCommand(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchAppConnectable(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppConnectable
                | 
                | Represents an application object that can be connected to
                | others.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_connectable = com_object

    def app_add_connector(self, i_class_type: str, o_new_app_cntr: SchAppConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppAddConnector(CATBSTR iClassType,
                | SchAppConnector oNewAppCntr)
                | 
                |     Add a connector.
                | 
                |     Parameters:
                | 
                |         iClassType
                |             Class type of the connector to be added. 
                |         oNewAppCntr
                |             The new Application Connector object created. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnectable
                |          Dim strVar1 As String
                |          Dim objArg2 As SchAppConnector
                |           ...
                |          objThisIntf.AppAddConnectorstrVar1,objArg2

        :param str i_class_type:
        :param SchAppConnector o_new_app_cntr:
        :rtype: None
        """
        return self.sch_app_connectable.AppAddConnector(i_class_type, o_new_app_cntr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_add_connector'
        # # vba_code = """
        # # Public Function app_add_connector(sch_app_connectable)
        # #     Dim iClassType (2)
        # #     sch_app_connectable.AppAddConnector iClassType
        # #     app_add_connector = iClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_get_reference_name(self, o_reference_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetReferenceName(CATBSTR oReferenceName)
                | 
                |     Get the reference name of a connectable. It will be displayed in
                |     catalogs.
                | 
                |     Parameters:
                | 
                |         oReferenceName
                |             The name of the reference 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnectable
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.AppGetReferenceNamestrVar1

        :param str o_reference_name:
        :rtype: None
        """
        return self.sch_app_connectable.AppGetReferenceName(o_reference_name)

    def app_list_connectables(
            self,
            i_l_cntble_class_filter: SchListOfBSTRs,
            o_l_cntbles: SchListOfObjects,
            o_l_cntrs_on_this_obj: SchListOfObjects,
            o_l_cntrs_on_connected: SchListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppListConnectables(SchListOfBSTRs
                | iLCntbleClassFilter,
                | SchListOfObjects oLCntbles,
                | SchListOfObjects oLCntrsOnThisObj,
                | SchListOfObjects oLCntrsOnConnected)
                | 
                |     Find all the application objects connected to this object through their
                |     connectors.
                | 
                |     Parameters:
                | 
                |         oLCntrClassFilter
                |             A list of all the class types for filtering the output application
                |             objects list. 
                |         oLCntbles
                |             A list of application objects connected to this object. (members
                |             are CATISchAppConnectable interface pointers). 
                |         oLCntrsOnThisObj
                |             A list of connectors on this object through which the connection is
                |             made. (members are CATISchAppConnector interface pointers).
                |             
                |         oLCntrsOnConnected
                |             A list of connectors on the connected objects through which the
                |             connection is made. (members are CATISchAppConnector interface pointers).
                |             Members in this list corresponds to those in oLCntrsOnThisObj in making the
                |             corresponding connections. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnectable
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchListOfObjects
                |          Dim objArg4 As SchListOfObjects
                |           ...
                |          objThisIntf.AppListConnectablesobjArg1,objArg2,objArg3,objArg4

        :param SchListOfBSTRs i_l_cntble_class_filter:
        :param SchListOfObjects o_l_cntbles:
        :param SchListOfObjects o_l_cntrs_on_this_obj:
        :param SchListOfObjects o_l_cntrs_on_connected:
        :rtype: None
        """
        return self.sch_app_connectable.AppListConnectables(
            i_l_cntble_class_filter.com_object,
            o_l_cntbles.com_object,
            o_l_cntrs_on_this_obj.com_object,
            o_l_cntrs_on_connected.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_list_connectables'
        # # vba_code = """
        # # Public Function app_list_connectables(sch_app_connectable)
        # #     Dim iLCntbleClassFilter (2)
        # #     sch_app_connectable.AppListConnectables iLCntbleClassFilter
        # #     app_list_connectables = iLCntbleClassFilter
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_list_connectors(self, i_l_cntr_class_filter: SchListOfBSTRs) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListConnectors(SchListOfBSTRs iLCntrClassFilter) As
                | SchListOfObjects
                | 
                |     Find all the connectors of this application object.
                | 
                |     Parameters:
                | 
                |         oLCntrClassFilter
                |             A list of all the class types for filtering the output connector
                |             list. 
                |         oLCntrs
                |             A list of connectors included in this connection. (members are
                |             CATISchAppConnector interface pointers). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnectable
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchListOfObjects
                |           ...
                |          Set objArg2 = objThisIntf.AppListConnectors(objArg1)

        :param SchListOfBSTRs i_l_cntr_class_filter:
        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_app_connectable.AppListConnectors(i_l_cntr_class_filter.com_object))

    def app_list_valid_cntr_types(self) -> SchListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListValidCntrTypes() As SchListOfBSTRs
                | 
                |     List the valid application connector types allowed to be
                |     created.
                | 
                |     Parameters:
                | 
                |         oLValidCntrTypes
                |             A list of connector class types allowed. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnectable
                |          Dim objArg1 As SchListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.AppListValidCntrTypes

        :rtype: SchListOfBSTRs
        """
        return SchListOfBSTRs(self.sch_app_connectable.AppListValidCntrTypes())

    def app_remove_connector(self, i_cntr_to_remove: SchAppConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppRemoveConnector(SchAppConnector iCntrToRemove)
                | 
                |     Remove a connector.
                | 
                |     Parameters:
                | 
                |         iCntrToRemove
                |             The application connector object to be removed 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnectable
                |          Dim objArg1 As SchAppConnector
                |           ...
                |          objThisIntf.AppRemoveConnectorobjArg1

        :param SchAppConnector i_cntr_to_remove:
        :rtype: None
        """
        return self.sch_app_connectable.AppRemoveConnector(i_cntr_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_remove_connector'
        # # vba_code = """
        # # Public Function app_remove_connector(sch_app_connectable)
        # #     Dim iCntrToRemove (2)
        # #     sch_app_connectable.AppRemoveConnector iCntrToRemove
        # #     app_remove_connector = iCntrToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_set_reference_name(self, i_reference_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppSetReferenceName(CATBSTR iReferenceName)
                | 
                |     Set the reference name of a connectable. It will be displayed in
                |     catalogs.
                | 
                |     Parameters:
                | 
                |         iReferenceName
                |             The name of the reference 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnectable
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.AppSetReferenceNamestrVar1

        :param str i_reference_name:
        :rtype: None
        """
        return self.sch_app_connectable.AppSetReferenceName(i_reference_name)

    def __repr__(self):
        return f'SchAppConnectable(name="{self.name}")'
